Learn R Programming

stheoreme (version 1.2)

utild1clean: Vector Cleaner

Description

Function utild1clean is applied to a pair of vectors and clean them from outliers with a rule specified by user (outliers will be replaced by the threshold values)

Usage

utild1clean(arr0, arr1, method = "bothends", nsigma = 3, d2=FALSE)

Arguments

arr0
vector of values/outcomes to be cleaned
arr1
vector of values/outcomes to be cleaned
method
specifies if outliers are to be removed from one or both side of array value distribution

method='bothends' remove otliers from both side of a distributon (default)

method='left' remove otliers from left side

method='right' remove otliers from right side

nsigma
number of sigmas to be considered as threshold for outlier removal
d2
works exactly as utild2clean when TRUE

Value

clean0
result of arr0 cleaning
clean1
result of arr1 cleaning

See Also

utild2clean

Examples

Run this code

s0<-c(rep(c(1,3,7,10),3), -23)
s1<-c(1:7)

s0; s1
a<-utild1clean(arr0=s0, arr1=s1); a
a<-utild1clean(s0, s1, method='right', nsigma=0.8); a

Run the code above in your browser using DataLab