Learn R Programming

stheoreme (version 1.2)

utild2filt: Gaussian Filter for Matrices

Description

The function is applied to a pair of matrices as a lowpass 2d gaussian filter to clean them from high frequency components

Usage

utild2filt(d2arr0, d2arr1, outsize = 2, strong = 1)

Arguments

d2arr0
vector to be filtered
d2arr1
vector to be filtered
outsize
radius of gaussian filter kernel
strong
multiplication factor defining the sigma of gaussian filter kernel as sigma=outsize*strong

Value

filt0
matrix being the result of d2arr0 filtration
filt1
matrix being the result of d2arr1 filtration

See Also

utild1filt

Examples

Run this code
s0<-array(c(1,4,5,8,3), c(6,6))
s1<-array(c(1,1,1,1,1,8,1,1,1,1,1,1), c(5,6))

s0; s1
utild2filt(d2arr0=s0, d2arr1=s1)
utild2filt(s0, s1, outsize=1)
utild2filt(s0, s1, strong=.2)

Run the code above in your browser using DataLab