Learn R Programming

stheoreme (version 1.2)

utild2group: Matrix Framer

Description

The function is applied to a pair of matrices in order to split them into NxN pixel frames and calculate respective matrices of frame means, there N is specified by user

Usage

utild2group(d2arr0, d2arr1, radius = 1, method = "split1")

Arguments

d2arr0
original matrix
d2arr1
original matrix
radius
sets the size of a single frame as N=(2*radius+1) points/pixels
method
sets the division of original array by a sequence of frames in different manner

method='split1' (the default) sets a sequence of frames as: frame11(1...N by 1...N), frame12(1...N by N+1,..2*N), frame21(N+1,..2*N by 1,..N), frame22(N+1,..2*N by N+1,..2*N), frame23(N+1,..2*N by 2*N+1,..3*N),etc

method='splitN' sets a sequence of frames as: frame11(1...N by 1...N), frame12(1...N by 2,..N+1), frame21(2,..N+1 by 1...N ), frame22(2,..N+1 by 2,..N+1), frame23(2,..N+1 by 3...N+2 ), etc

Value

group0
matrix containing mean values of individual frames the original d2arr0 was divided by
group1
matrix containing mean values of individual frames the original d2arr1 was divided by

See Also

utild1group

Examples

Run this code
s0<-array(c(-1,1,3,7,10),c(14,12))
s1<-array(c(1:156),c(12,13))

s0; s1
a<-utild2group(d2arr0=s0, d2arr1=s1); a
a<-utild2group(s0, s1, radius=2, method='splitN'); a
a<-utild2group(s0, s1, radius=3); a

Run the code above in your browser using DataLab